@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = 'Christian Heider Nielsen'
-__doc__ = r'''
+__author__ = "Christian Heider Nielsen"
+__doc__ = r"""
 
            Created on 26-01-2021
-           '''
-from .first_arg_identifier import *
\ No newline at end of file
+           """
+from .first_arg_identifier import *
