@@ -32,11 +32,11 @@ def is_positive_and_mod_zero(
     else return alt
 
 
-    @param mod:
-    @param counter:
-    @param ret:
-    @param alt:
-    @return:"""
+    :param mod:
+    :param counter:
+    :param ret:
+    :param alt:
+    :return:"""
 
     return ret if (mod > 0 and (counter % mod == 0)) else alt
 
@@ -52,13 +52,13 @@ def is_zero_or_mod_below(
     else return alt
 
 
-    @param below:
-    @type below:
-    @param mod:
-    @param counter:
-    @param ret:
-    @param alt:
-    @return:"""
+    :param below:
+    :type below:
+    :param mod:
+    :param counter:
+    :param ret:
+    :param alt:
+    :return:"""
     return ret if (mod == 0 or (counter % mod < below)) else alt
 
 
@@ -73,19 +73,19 @@ def is_zero_or_mod_zero(
     else return alt
 
 
-    @param mod:
-    @param counter:
-    @param ret:
-    @param alt:
-    @return:"""
+    :param mod:
+    :param counter:
+    :param ret:
+    :param alt:
+    :return:"""
     return ret if (mod == 0 or (counter % mod == 0)) else alt
 
 
 def is_none_or_zero_or_negative(obj: Any) -> bool:
     """
 
-    @param obj:
-    @return:"""
+    :param obj:
+    :return:"""
     is_none = obj is None
     is_negative = False
     if isinstance(obj, (int, float)):
@@ -98,15 +98,18 @@ def is_none_or_zero_or_negative(obj: Any) -> bool:
 def is_none_or_zero_or_negative_or_mod_zero(mod: int, counter: int, **kwargs) -> bool:
     """
 
-    @param mod:
-    @param counter:
-    @param kwargs:
-    @return:"""
+    :param mod:
+    :param counter:
+    :param kwargs:
+    :return:"""
     return is_none_or_zero_or_negative(mod) or is_zero_or_mod_zero(
         mod, counter, **kwargs
     )
 
 
+
+
+
 if __name__ == "__main__":
     assert is_zero_or_mod_below(5, 3, 7) == True
     assert is_zero_or_mod_below(5, 2, 4) == False
