@@ -215,12 +215,14 @@ class OrderedSet(MutableSet[T], Sequence[T]):
                 item_index = self.add(item)
         except TypeError:
             raise ValueError(
-                "Argument needs to be an iterable, got %s" % type(sequence)
+                f"Argument needs to be an iterable, got {type(sequence)}"
             )
         return item_index
 
     @overload
     def index(self, key: T) -> int:
+        """
+        """
         ...
 
     def index(self, key: Sequence[T]) -> List[int]:
@@ -312,8 +314,8 @@ class OrderedSet(MutableSet[T], Sequence[T]):
 
     def __repr__(self) -> str:
         if not self:
-            return "%s()" % (self.__class__.__name__,)
-        return "%s(%r)" % (self.__class__.__name__, list(self))
+            return f"{self.__class__.__name__}()"
+        return f"{self.__class__.__name__}({list(self)!r})"
 
     def __eq__(self, other: Any) -> bool:
         """
