@@ -15,67 +15,71 @@ __all__ = [
     "call_identity",
     "args_sink",
     "identity",
-]
+    ]
 
 import operator
 from functools import reduce
 from typing import Any, Dict, Iterable, Tuple, Union
 
-from warg import drop_unused_kws
+from warg import Number, drop_unused_kws
 
 
 def identity(a: Any) -> Any:
-    return a
+  """
+    """
+  return a
 
 
 @drop_unused_kws
 def kws_sink(*args) -> Tuple[Any, ...]:
-    """
+  """
     Returns args without any modification what so ever. Drops kws
     :param x:
     :return:"""
-    return args
+  return args
 
 
-def call_identity(*args, **kwargs) -> Tuple[Tuple[Any], Dict[str, Any]]:
-    """
+def call_identity(*args, **kwargs) -> Tuple[Tuple[Any, ...], Dict[str, Any]]:
+  """
 
     :param args:
     :param kwargs:
     :return:"""
-    return args, kwargs
+  return args, kwargs
 
 
+# noinspection PyUnusedLocal
 def args_sink(*args, **kwargs) -> Dict[str, Any]:
-    """
+  """
 
     :param args:
     :param kwargs:
     :return:"""
-    return kwargs
+  return kwargs
 
 
+# noinspection PyUnusedLocal
 def sink(*args, **kwargs) -> None:
-    """
+  """
     Returns None, but accepts everything
 
     :param args:
     :param kwargs:
     :return:"""
-    return None
+  return None
 
 
-def prod(iterable: Iterable[Union[int, float]]) -> Union[int, float]:
-    """
+def prod(iterable: Iterable[Number]) -> Number:
+  """
     Calculate the product of the a Iterable of int or floats
     :param iterable:
     :return:"""
-    return reduce(operator.mul, iterable, 1)
+  return reduce(operator.mul, iterable, 1)
 
 
-def collate_first_dim(batch: Iterable) -> tuple:
-    """
+def collate_first_dim(batch: Iterable) -> Tuple:
+  """
 
     :param batch:
     :return:"""
-    return tuple(zip(*batch))
+  return tuple(zip(*batch))
